summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--Lib/email/MIMEBase.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/Lib/email/MIMEBase.py b/Lib/email/MIMEBase.py
index e6dda56..33216f6 100644
--- a/Lib/email/MIMEBase.py
+++ b/Lib/email/MIMEBase.py
@@ -11,14 +11,14 @@ import Message
class MIMEBase(Message.Message):
"""Base class for MIME specializations."""
- def __init__(self, _major, _minor, **_params):
+ def __init__(self, _maintype, _subtype, **_params):
"""This constructor adds a Content-Type: and a MIME-Version: header.
The Content-Type: header is taken from the _major and _minor
arguments. Additional parameters for this header are taken from the
keyword arguments.
"""
Message.Message.__init__(self)
- ctype = '%s/%s' % (_major, _minor)
+ ctype = '%s/%s' % (_maintype, _subtype)
self.add_header('Content-Type', ctype, **_params)
self['MIME-Version'] = '1.0'
@@ -11,14 +11,14 @@ import Message
"""This constructor adds a Content-Type: and a MIME-Version: header.
- The Content-Type: header is taken from the _major and _minor
+ The Content-Type: header is taken from the _maintype and _subtype
arguments. Additional parameters for this header are taken from the
keyword arguments.